---
name: Bug report
about: Create a report if something doesn't work quite right.
title: ''
labels: bug
assignees: ''
---

<!-- Provide a general summary of the issue -->

## Description
<!-- Provide a more detailed introduction to the issue itself, and why you consider it to be a bug -->
<!-- If you can, add a minimal example which reproduces the bug -->

## Expected Behavior
<!-- Tell us what should happen -->

## Actual Behavior
<!-- Tell us what goes wrong and happens instead -->

## Error Message
<!-- Paste any terminal output and error message you encounter here to help illustrate the problem -->

## Your Environment
<!-- Include relevant details about the environment you experienced the bug in -->
* The `atlite` version used:
* How you installed `atlite` (`conda`, `pip` or `github`):
* Operating System:
* My environment:
    <details>
      <summary>(output of `conda list`)</summary>
      ```
        <!-- output of `conda list` -->
      ```
    </details>


